# RFC: Polyfill modes

* **Authors**: -
* **Date**: -
* **Status**: Draft

## Abstract

Our current polyfill algorithm allocates cells to polygons based on whether the center of the cell falls within the polygon, using Cartesian geometry. This proposal outlines options for expanding the polyfill algorithm to allow for different containment modes (e.g. wholly contained cells, intersecting cells) and spherical geometry.

## Motivation

*Why is this important?*

## Approaches

*What are the various options to address this issue?*

## Proposal

*What is the recommended approach?*